@@ -1,5 +1,5 @@
 #   Copyright (C) 2006-2007 Daniel Burrows
-#   Copyright (C) 2021 Scott Hansen
+#   Copyright (C) 2023 Scott Hansen
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -211,6 +211,10 @@ class URLChooser:
         self.items, self.urls = self.process_urls(extractedurls,
                                                   dedupe=dedupe,
                                                   shorten=self.shorten)
+        # Original version of all items
+        self.items_orig = self.items
+        # Store items grouped into sections
+        self.items_org = grp_list(self.items)
         # Store 'compact' mode items
         self.items_com = [i for i in self.items if
                           isinstance(i, urwid.Columns) is True]
@@ -218,10 +222,6 @@ class URLChooser:
             self.items, self.items_com = self.items_com, self.items
         self.urls_unesc = [i.replace('\\', '') for i in self.urls]
         self.unesc = False
-        # Original version of all items
-        self.items_orig = self.items
-        # Store items grouped into sections
-        self.items_org = grp_list(self.items)
         listbox = urwid.ListBox(self.items)
         self.header = (":: F1 - help/keybindings :: "
                        "q - quit :: "
@@ -399,6 +399,9 @@ class URLChooser:
         self.headerwid = urwid.AttrMap(urwid.Text(
             self.header.format(self.link_open_modes[0], len(self.queue))), 'header')
         self.top.base_widget.header = self.headerwid
+        label = self.items[fpo][1].label
+        if not label.startswith("* "):
+            self.items[fpo][1].set_label(f"* {label}")
 
     def _del_url(self):
         """d"""
@@ -412,6 +415,9 @@ class URLChooser:
             self.headerwid = urwid.AttrMap(urwid.Text(
                 self.header.format(self.link_open_modes[0], len(self.queue))), 'header')
             self.top.base_widget.header = self.headerwid
+            label = self.items[fpo][1].label
+            if label.startswith("* "):
+                self.items[fpo][1].set_label(label.lstrip("* "))
         except ValueError:
             pass
 
@@ -464,8 +470,7 @@ class URLChooser:
         if self.urls:
             self.search = True
             if self.compact is True:
-                self.compact = False
-                self.items, self.items_com = self.items_com, self.items
+                self._context()
         else:
             return
         self.no_matches = False
